@@ -1,28 +1,27 @@
+from typing import Any, Dict, List, Literal, Optional, Tuple
+
 import json
 import os
-from typing import Any, Dict, List, Literal, Optional, Tuple
-from aiconfig.default_parsers.claude import ClaudeBedrockModelParser
-
 import requests
 import yaml
-from aiconfig.callback import CallbackEvent, CallbackManager
-from aiconfig.default_parsers.anyscale_endpoint import (
+
+from .callback import CallbackEvent, CallbackManager
+from .default_parsers.anyscale_endpoint import (
     DefaultAnyscaleEndpointParser,
 )
-from aiconfig.default_parsers.openai import DefaultOpenAIParser
-from aiconfig.default_parsers.gemini import GeminiModelParser
-from aiconfig.default_parsers.palm import PaLMChatParser, PaLMTextParser
-from aiconfig.model_parser import InferenceOptions, ModelParser
-
-from aiconfig.schema import JSONObject
-
+from .default_parsers.claude import ClaudeBedrockModelParser
 from .default_parsers.dalle import DalleImageGenerationParser
+from .default_parsers.openai import DefaultOpenAIParser
+from .default_parsers.gemini import GeminiModelParser
 from .default_parsers.hf import HuggingFaceTextGenerationParser
+from .default_parsers.palm import PaLMChatParser, PaLMTextParser
+from .model_parser import InferenceOptions, ModelParser
+
 from .registry import (
     ModelParserRegistry,
     update_model_parser_registry_with_config_runtime,
 )
-from .schema import AIConfig, Prompt
+from .schema import AIConfig, JSONObject, Prompt
 from .util.config_utils import is_yaml_ext
 
 gpt_models_main = [
@@ -53,13 +52,13 @@ for model in dalle_image_generation_models:
 ModelParserRegistry.register_model_parser(
     DefaultAnyscaleEndpointParser("AnyscaleEndpoint")
 )
+ModelParserRegistry.register_model_parser(ClaudeBedrockModelParser())
+for model in gpt_models_extra:
+    ModelParserRegistry.register_model_parser(DefaultOpenAIParser(model))
 ModelParserRegistry.register_model_parser(
     GeminiModelParser("gemini-pro"), ["gemini-pro"]
 )
-ModelParserRegistry.register_model_parser(ClaudeBedrockModelParser())
 ModelParserRegistry.register_model_parser(HuggingFaceTextGenerationParser())
-for model in gpt_models_extra:
-    ModelParserRegistry.register_model_parser(DefaultOpenAIParser(model))
 ModelParserRegistry.register_model_parser(PaLMChatParser())
 ModelParserRegistry.register_model_parser(PaLMTextParser())
 
@@ -93,7 +92,7 @@ class AIConfigRuntime(AIConfig):
 
         This method creates a new AI configuration with the provided parameters and sets it as the current AI configuration.
         """
-        return cls(
+        config: "AIConfigRuntime" = cls(
             **{
                 "name": name,
                 "description": description,
@@ -102,6 +101,8 @@ class AIConfigRuntime(AIConfig):
                 "prompts": prompts,
             }
         )
+        update_model_parser_registry_with_config_runtime(config)
+        return config
 
     @classmethod
     def load(cls, config_filepath: str) -> "AIConfigRuntime":
